@@ -1,3 +1,4 @@
+import os
 import sys
 import warnings
 from functools import cache
@@ -6,6 +7,15 @@ from django.conf import settings
 from django.dispatch import receiver
 from django.test.signals import setting_changed
 
+
+def _is_running_tests():
+    """
+    Helper function to support testing default value for
+    IS_RUNNING_TESTS
+    """
+    return "test" in sys.argv or "PYTEST_VERSION" in os.environ
+
+
 CONFIG_DEFAULTS = {
     # Toolbar options
     "DISABLE_PANELS": {
@@ -43,7 +53,8 @@ CONFIG_DEFAULTS = {
     "SQL_WARNING_THRESHOLD": 500,  # milliseconds
     "OBSERVE_REQUEST_CALLBACK": "debug_toolbar.toolbar.observe_request",
     "TOOLBAR_LANGUAGE": None,
-    "IS_RUNNING_TESTS": "test" in sys.argv,
+    "TOOLBAR_STORE_CLASS": "debug_toolbar.store.MemoryStore",
+    "IS_RUNNING_TESTS": _is_running_tests(),
     "UPDATE_ON_FETCH": False,
 }
 
@@ -69,6 +80,7 @@ PANELS_DEFAULTS = [
     "debug_toolbar.panels.alerts.AlertsPanel",
     "debug_toolbar.panels.cache.CachePanel",
     "debug_toolbar.panels.signals.SignalsPanel",
+    "debug_toolbar.panels.community.CommunityPanel",
     "debug_toolbar.panels.redirects.RedirectsPanel",
     "debug_toolbar.panels.profiling.ProfilingPanel",
 ]
