@@ -17,7 +17,11 @@ urlpatterns = [
     path("non_ascii_request/", views.regular_view, {"title": NonAsciiRepr()}),
     path("new_user/", views.new_user),
     path("execute_sql/", views.execute_sql),
+    path("execute_json_sql/", views.execute_json_sql),
+    path("execute_union_sql/", views.execute_union_sql),
     path("async_execute_sql/", views.async_execute_sql),
+    path("async_execute_json_sql/", views.async_execute_json_sql),
+    path("async_execute_union_sql/", views.async_execute_union_sql),
     path("async_execute_sql_concurrently/", views.async_execute_sql_concurrently),
     path("cached_view/", views.cached_view),
     path("cached_low_level_view/", views.cached_low_level_view),
@@ -25,6 +29,7 @@ urlpatterns = [
     path("redirect/", views.redirect_view),
     path("ajax/", views.ajax_view),
     path("login_without_redirect/", LoginView.as_view(redirect_field_name=None)),
+    path("csp_view/", views.csp_view),
     path("admin/", admin.site.urls),
     path("__debug__/", include("debug_toolbar.urls")),
 ]
