@@ -8,12 +8,41 @@ from django.shortcuts import render
 from django.template.response import TemplateResponse
 from django.views.decorators.cache import cache_page
 
+from tests.models import PostgresJSON
+
 
 def execute_sql(request):
     list(User.objects.all())
     return render(request, "base.html")
 
 
+def execute_json_sql(request):
+    list(PostgresJSON.objects.filter(field__contains={"foo": "bar"}))
+    return render(request, "base.html")
+
+
+async def async_execute_json_sql(request):
+    list_store = []
+    # make async query with filter, which is compatible with async for.
+    async for obj in PostgresJSON.objects.filter(field__contains={"foo": "bar"}):
+        list_store.append(obj)
+    return render(request, "base.html")
+
+
+def execute_union_sql(request):
+    list(User.objects.all().union(User.objects.all(), all=True))
+    return render(request, "base.html")
+
+
+async def async_execute_union_sql(request):
+    list_store = []
+    # make async query with filter, which is compatible with async for.
+    users = User.objects.all().union(User.objects.all(), all=True)
+    async for user in users:
+        list_store.append(user)
+    return render(request, "base.html")
+
+
 async def async_execute_sql(request):
     """
     Some query API can be executed asynchronously but some requires
